@@ -6,12 +6,12 @@ Mojolicious::Plugin::OAuth2::Server - Easier implementation of an OAuth2
 Authorization Server / Resource Server with Mojolicious
 
 =for html
-<a href='https://travis-ci.org/leejo/mojolicious-plugin-oauth2-server?branch=master'><img src='https://travis-ci.org/leejo/mojolicious-plugin-oauth2-server.svg?branch=master' alt='Build Status' /></a>
-<a href='https://coveralls.io/r/leejo/mojolicious-plugin-oauth2-server?branch=master'><img src='https://coveralls.io/repos/leejo/mojolicious-plugin-oauth2-server/badge.png?branch=master' alt='Coverage Status' /></a>
+<a href='https://travis-ci.org/G3S/mojolicious-plugin-oauth2-server?branch=master'><img src='https://travis-ci.org/G3S/mojolicious-plugin-oauth2-server.svg?branch=master' alt='Build Status' /></a>
+<a href='https://coveralls.io/r/G3S/mojolicious-plugin-oauth2-server?branch=master'><img src='https://coveralls.io/repos/G3S/mojolicious-plugin-oauth2-server/badge.png?branch=master' alt='Coverage Status' /></a>
 
 =head1 VERSION
 
-0.22
+0.23
 
 =head1 SYNOPSIS
 
@@ -218,7 +218,7 @@ use Carp qw/ croak /;
 use Crypt::PRNG qw/ random_string /;
 use Try::Tiny;
 
-our $VERSION = '0.22';
+our $VERSION = '0.23';
 
 my %CLIENTS;
 my %AUTH_CODES;
@@ -1274,7 +1274,7 @@ This library is free software; you can redistribute it and/or modify it under
 the same terms as Perl itself. If you would like to contribute documentation
 or file a bug report then please raise an issue / pull request:
 
-    https://github.com/leejo/mojolicious-plugin-oauth2-server
+    https://github.com/G3S/mojolicious-plugin-oauth2-server
 
 =cut
 
